# ------------------------------------------------------------------------------
#
# Auto Eye
#
# Description
#   Auto Eye rotates camera in the direction of a mouse when the cursor is
#   outside the view area.
#
# Access
#   (Menu) View -> Auto Eye
#
# Requirements
#   * Microsoft Windows XP, Vista, 7, 8
#   * SketchUp 6 or later
#   * AMS_Library 1.0.8 or later
#
# Version
#   1.0.0
#
# Release Date
#   May 18, 2014
#
# Copyright
#   © 2014, Anton Synytsia (anton.synytsia@gmail.com).
#
# ------------------------------------------------------------------------------

require 'sketchup.rb'
require 'extensions.rb'

dir = File.dirname(__FILE__)
lib = File.join(dir, 'ams_Lib.rb')
win = ( RUBY_PLATFORM =~ /mswin|mingw/i )

continue = true

# Check operating system, and make decisions prior to loading.
unless win
  msg = "It seems your operating system is not Microsoft Windows. "
  msg << "Auto Eye extension might not operate on your OS.\n"
  msg << "Load the extension anyway?"
  input = UI.messagebox(msg, MB_YESNO)
  continue = false if (input == IDNO)
end

# Check for AMS Library.
if continue
  if File.exists?(lib)
    require 'ams_Lib.rb'
    if AMS::Lib::VERSION.delete('.').to_i < 108
      msg = "Auto Eye extension requires AMS Library version 1.0.8 or later! "
      msg << "Download AMS Library, extract it into the plugins folder, and restart SU.\n"
      msg << "Click OK to proceed to the library's homepage."
      input = UI.messagebox(msg, MB_OKCANCEL)
      if input == IDOK
        UI.openURL('http://sketchucation.com/forums/viewtopic.php?f=323&t=55067#p499835')
      end
      continue = false
    end
  else
    msg = "Auto Eye extension requires AMS Library! "
    msg << "Download AMS Library, extract it into the plugins folder, and restart SU.\n"
    msg << "Click OK to proceed to the library's homepage."
    input = UI.messagebox(msg, MB_OKCANCEL)
    if input == IDOK
      UI.openURL('http://sketchucation.com/forums/viewtopic.php?f=323&t=55067#p499835')
    end
    continue = false
  end
end

class AMS::Plugins::AutoEye

  NAME          = 'Auto Eye'.freeze
  VERSION       = '1.0.0'.freeze
  RELEASE_DATE  = 'May 18, 2014'.freeze

  # Create the extension.
  @extension = SketchupExtension.new NAME, 'ams_AutoEye/main.rb'

  desc = "Makes SU more user friendly by automatically rotating camera in the desired direction."

  # Attach some nice info.
  @extension.description    = desc
  @extension.version        = VERSION
  @extension.copyright      = 'Anton Synytsia © 2014'
  @extension.creator        = 'Anton Synytsia (anton.synytsia@gmail.com)'

  # Register and load the extension on start-up.
  Sketchup.register_extension @extension, true

  class << self
    attr_reader :extension
  end

end if continue
